@@ -9,14 +9,18 @@ markdownMap = {
     u"ENV": u"env",
     u"PLATFORM": u"platform",
     u"DATETIME": u"datetime",
-		u"LEVEL": u'level',
+		# u"LEVEL": u'level',
 		u"RELEASE": u'release'
 }
 
 defaultMarkdown = u'''
-### {PROJECT_NAME}
-#### {TITLE}
-{MESSAGE}
+### 项目：{PROJECT_NAME}-{TITLE}
+####  信息：{MESSAGE}
+> 版本：{RELEASE}
+> 环境：{ENV}
+> 项目平台：{PLATFORM}
+> 时间：{DATETIME}
+
 [查看详情]({URL})
 '''
 
